@@ -14,7 +14,7 @@ import h5py
 from sidpy.sid import Translator
 from sidpy.hdf.hdf_utils import write_simple_attrs
 
-from pyUSID.io.write_utils import Dimension
+from pyUSID import Dimension
 from pyUSID.io.hdf_utils import create_indexed_group, write_main_dataset, \
     write_ind_val_dsets
 from .df_utils.base_utils import read_binary_data
