@@ -15,7 +15,8 @@ from igor import binarywave as bw
 from sidpy.sid import Translator
 from sidpy.hdf.hdf_utils import write_simple_attrs
 
-from pyUSID.io.write_utils import VALUES_DTYPE, Dimension
+from pyUSID.io.anc_build_utils import VALUES_DTYPE
+from pyUSID import Dimension
 from pyUSID.io.hdf_utils import create_indexed_group, write_main_dataset, \
     write_ind_val_dsets
 
