@@ -15,18 +15,22 @@ from sklearn.utils import gen_batches
 from sklearn.utils.extmath import randomized_svd
 
 from sidpy.hdf.reg_ref import get_indices_for_region_ref, create_region_reference
-from sidpy.hdf.hdf_utils import get_attr, write_simple_attrs
+from sidpy.hdf.hdf_utils import get_attr, write_simple_attrs, copy_attributes
 from sidpy.proc.comp_utils import get_available_memory
 from sidpy.base.string_utils import format_time
 from sidpy.hdf.dtype_utils import check_dtype, stack_real_to_target_dtype
 
 from pyUSID.processing.process import Process
 from .proc_utils import get_component_slice
-from pyUSID.io.hdf_utils import find_results_groups, copy_attributes, \
+from pyUSID.io.hdf_utils import find_results_groups, \
     reshape_to_n_dims, write_main_dataset, create_results_group, \
-    create_indexed_group
-from pyUSID.io.write_utils import Dimension, calc_chunks
-from pyUSID import USIDataset
+    create_indexed_group, find_dataset
+from pyUSID.io.anc_build_utils import calc_chunks
+from pyUSID import USIDataset, Dimension
+
+import h5py
+from matplotlib import pyplot as plt
+from pyUSID.viz import plot_utils
 
 
 class SVD(Process):
@@ -136,6 +140,12 @@ class SVD(Process):
         if not success:
             raise ValueError('Could not reshape U to N-Dimensional dataset! Error:' + success)
 
+        # When the source dataset has a singular valued spectroscopic dimension
+        # stack_real_to_target causes V to lose all its dimensions
+        if self.__v.ndim == 0:
+            # However, we want V to be 2D:
+            self.__v = np.atleast_2d(self.__v)
+
         v_mat, success = reshape_to_n_dims(self.__v, h5_pos=np.expand_dims(np.arange(self.__u.shape[1]), axis=1),
                                            h5_spec=self.h5_main.h5_spec_inds)
         if not success:
@@ -452,15 +462,15 @@ def plot_svd(h5_main, savefig=False, num_plots = 16, **kwargs):
     
     if isinstance(h5_main, h5py.Group):
 
-        _U = usid.hdf_utils.find_dataset(h5_main, 'U')[-1]
-        _V = usid.hdf_utils.find_dataset(h5_main, 'V')[-1]
+        _U = find_dataset(h5_main, 'U')[-1]
+        _V = find_dataset(h5_main, 'V')[-1]
         units = 'arbitrary (a.u.)'
         h5_spec_vals = np.arange(_V.shape[1])
         h5_svd_group = _U.parent
 
     else:
 
-        h5_svd_group = usid.hdf_utils.find_results_groups(h5_main, 'SVD')[-1]
+        h5_svd_group = find_results_groups(h5_main, 'SVD')[-1]
         units = h5_main.attrs['quantity']
         h5_spec_vals = h5_main.get_spec_values('Time')
     
@@ -468,7 +478,7 @@ def plot_svd(h5_main, savefig=False, num_plots = 16, **kwargs):
     h5_V = h5_svd_group['V']
     h5_S = h5_svd_group['S']
     
-    _U = usid.USIDataset(h5_U)
+    _U = USIDataset(h5_U)
     [num_rows, num_cols] = _U.pos_dim_sizes
     
     abun_maps = np.reshape(h5_U[:,:16], (num_rows, num_cols,-1))
@@ -487,13 +497,13 @@ def plot_svd(h5_main, savefig=False, num_plots = 16, **kwargs):
     if savefig:
         plt.savefig('Cumulative_variance_plot.png')
     
-    fig_skree, axes = usid.viz.plot_utils.plot_scree(h5_S, title='Scree plot')
+    fig_skree, axes = plot_utils.plot_scree(h5_S, title='Scree plot')
     fig_skree.tight_layout()
 
     if savefig:
         plt.savefig('Scree_plot.png')
     
-    fig_abun, axes = usid.viz.plot_utils.plot_map_stack(abun_maps, num_comps=num_plots, title='SVD Abundance Maps',
+    fig_abun, axes = plot_utils.plot_map_stack(abun_maps, num_comps=num_plots, title='SVD Abundance Maps',
                                                   color_bar_mode='single', cmap='inferno', reverse_dims=True, 
                                                   fig_mult=(3.5,3.5), facecolor='white', **kwargs)
     fig_abun.tight_layout()
@@ -501,7 +511,7 @@ def plot_svd(h5_main, savefig=False, num_plots = 16, **kwargs):
         plt.savefig('Abundance_maps.png')
     
 
-    fig_eigvec, axes = usid.viz.plot_utils.plot_curves(h5_spec_vals*1e3, eigen_vecs, use_rainbow_plots=False, 
+    fig_eigvec, axes = plot_utils.plot_curves(h5_spec_vals*1e3, eigen_vecs, use_rainbow_plots=False, 
                                                  x_label='Time (ms)', y_label=units, 
                                                  num_plots=num_plots, subtitle_prefix='Component', 
                                                  title='SVD Eigenvectors', evenly_spaced=False, 
